#!/bin/bash

if [ $1 == "clean" ]; then
  make clean
  exit 0
fi

if [ ! -d "${JC_WORKSPACE}" ]; then
  echo "JC_WORKSPACE \"${JC_WORKSPACE}\" is not a valid directory"
  exit 255
fi

# check if FX3 library files exist
if [ ! -f ../fw_lib/1_3_4/fx3_release/libcyu3sport.a ] || \
   [ ! -f ../fw_lib/1_3_4/fx3_release/libcyu3lpp.a ] || \
   [ ! -f ../fw_lib/1_3_4/fx3_release/libcyfxapi.a ] || \
   [ ! -f ../fw_lib/1_3_4/fx3_release/libcyu3threadx.a ]; then
   echo -e "downloding FX3 library files...\n"
   FX3_LIB_DIR="/opt/jc/third_party"
   mkdir -p $FX3_LIB_DIR
   # download the FX3 library tar file
   jc_artifact download 92212d6d781070e3927021887c2a2d7a955d0c8762f529e9570b52cfc9bcf52a -d nZBIz70HiKsKW4O2 -o /tmp/fx3.tar
   # uncompress the files
   tar xvf /tmp/fx3.tar -C $FX3_LIB_DIR
fi

make clean

cd `dirname $0`
pwd
crc=`crc32 ../../include/wr_cam10_def.h`
ct=`date +%s`
branch=$(git rev-parse --abbrev-ref HEAD)
hash=$(git rev-parse --short HEAD)
header="cam10_def_crc.h"
echo '#ifndef _CAM10_DEF_CRC_H'     > $header
echo '#define _CAM10_DEF_CRC_H'    >> $header
echo "#define CAM10_DEF_CRC 0x$crc" >> $header
echo "#define CAM10_DEF_TIME $ct" >> $header
echo "#define CAM10_BRANCH \"$branch\"" >> $header
echo "#define CAM10_BRANCH_HASH   0x$hash" >> $header
echo '#endif' >> $header

gcc -o elf2img ../util/elf2img/elf2img.c

# build the cam10 firmware image: uvc_cam10.img
make
